@@ -551,6 +551,7 @@ class Ped(object):
         if a.mom is None and a.dad is None and b.mom is None and b.dad is None:
             return 'unrelated'
 
+        print("siblings?", a, b, file=sys.stderr)
         if a.mom == b.mom and a.dad == b.dad and None not in (a.mom, a.dad):
             return 'full siblings'
 
@@ -666,8 +667,9 @@ class Ped(object):
                   skip_missing=True,
                   plot=False,
                   cutoff=0.6,
-                  n_sites=100000,
-                  pars=('X:10000-2781479', 'X:155701382-156030895')):
+                  n_sites=10000,
+                  # these PARs work for GRCh37 and GRCh38
+                  pars=('X:10000-2781479', 'X:154931044-156030895')):
         """
         Check that the sex reported in the ped file matches that inferred
         using the genotypes in `vcf_path` using the ratio of HET / (HOM_REF +
@@ -694,6 +696,11 @@ class Ped(object):
         pars = [(x[0], [int(p) for p in x[1].split('-')]) for x in pars]
 
         chrom = pars[0][0]
+        # just skip the PAR with a query rather than iterating over it.
+        s, e = pars[0][1]
+        if s < 20000:
+            chrom += ":" + str(e + 1)
+
         try:
             next(vcf(chrom))
         except StopIteration:  # check for chrX
@@ -722,7 +729,12 @@ class Ped(object):
             if any(s <= variant.start and e >= variant.start for chrom, (s, e) in pars):
                 skipped += 1
                 continue
-            depth_filter = variant.gt_depths >= min_depth
+            if np.all(variant.gt_depths < 0):
+                # if not samples have depths, then we assume the vcf doesn't have them and
+                # we use all samples
+                depth_filter = np.ones_like(hom_ref)
+            else:
+                depth_filter = variant.gt_depths >= min_depth
             gt_types = variant.gt_types
 
             hom_ref += (gt_types == 0) & depth_filter
@@ -732,6 +744,7 @@ class Ped(object):
             if kept >= n_sites: break
 
         # this should be high for females and low for males
+        hom_alt[hom_alt == 0] = 1
         het_ratio = het.astype(float) / (hom_alt)
         log.info("sex-check: %s skipped / %d kept" % (skipped, kept))
 
@@ -827,16 +840,18 @@ class Ped(object):
         return pd.DataFrame(res)
 
     def het_check(self, vcf_path, plot=False, ncpus=1, min_depth=8,
-                  sites=op.join(op.dirname(__file__), '1kg.sites'),
+                  sites=op.join(op.dirname(__file__), 'GRCH37.sites'),
                   **kwargs):
         """
         kwargs is not used, but added here to allow same args as ped_check
         """
+
         import cyvcf2
         import numpy as np
         if ncpus > 16:
             ncpus = 16
 
+        sitesfile = sites
         samps = [x.sample_id for x in self.samples()]
         vcf = cyvcf2.VCF(vcf_path, gts012=True, samples=samps)
         if sorted(vcf.samples) != sorted(samps):
@@ -860,7 +875,7 @@ class Ped(object):
                 pca_plot = "%s.%s%s" % (pca_plot, "pca.", ext)
         else:
             pca_plot = False
-        pca_df, background_pca_df = pca(pca_plot, gt_types, sites)
+        pca_df, background_pca_df = pca(pca_plot, sitesfile, gt_types, sites)
 
         # not find outliers.
         depth = np.array([v['median_depth'] for v in sample_ranges.values()])
@@ -925,7 +940,7 @@ class Ped(object):
 
     def ped_check(self, vcf, ncpus=1, plot=False, min_depth=5, each=1,
             prefix='',
-            sites=op.join(op.dirname(__file__), '1kg.sites')):
+            sites=op.join(op.dirname(__file__), 'GRCH37.sites')):
         """
         Given the current pedigree and a VCF of genotypes, find sample-pairs where
         the relationship reported in the pedigree file do not match those inferred
@@ -937,6 +952,7 @@ class Ped(object):
         :param min_depth int: minimum required depth.
         :return: pandas.DataFrame
         """
+
         import cyvcf2
         import numpy as np
         import pandas as pd
@@ -992,7 +1008,7 @@ class Ped(object):
             rels.append(max(0, self.relatedness_coefficient(aid, bid)))
 
         df.loc[np.asarray(parent_is), 'pedigree_parents'] = True
-        df.loc[idxs, 'pedigree_relatedness'] = np.asarray(rels, np.float32)
+        df.loc[idxs, 'pedigree_relatedness'] = np.maximum(np.array(-0.1), np.asarray(rels, np.float32))
 
 
         df['tmpibs0'] = (df['ibs0'] / df['n'].astype(np.float32)).astype(np.float32)
@@ -1002,13 +1018,13 @@ class Ped(object):
 
         pr = df['pedigree_relatedness']
         df["rel_difference"] = (pr - df['rel']).astype(np.float32)
-        # make the column order a bit more sane.
+
         if len(ped_samples) > 200:
             rd = np.abs(df['rel_difference']) > 0.17
 
             sampling_rate = 1 / (len(ped_samples)**0.6)
             ru = (np.random.uniform(size=df.shape[0]) < sampling_rate)
-            df['keep'] = df.eval('parent_error | sample_duplication_error | predicted_parents| @rd | @ru' +
+            df['keep'] = df.eval('parent_error | sample_duplication_error | predicted_parents| @rd | @ru ' +
                     '| (rel > 0.17) | (tmpibs0 < 0.04) | (pedigree_relatedness > 0)')
 
             df['keep'] |= same_fam
@@ -1033,7 +1049,7 @@ class Ped(object):
         #df['rel_difference'][df['rel_difference'] == 0] = 0.001
         df.loc[df['rel_difference'] == 0, 'rel_difference'] == 0.001
 
-        sub = df.eval('((rel > 0.1) & (pedigree_relatedness < 0.05)) | ((rel < 0.05) & (pedigree_relatedness > 0.1)) | (rel_difference > 0.1) | (rel_difference < -0.1)')
+        sub = df.eval('((rel > 0.1) & (pedigree_relatedness < 0.05)) | ((rel < 0.05) & (pedigree_relatedness > 0.1)) | (abs(rel_difference) > 0.1)')
         da = df[sub].groupby('sample_a')['rel_difference'].agg(asum)
         db = df[sub].groupby('sample_b')['rel_difference'].agg(asum)
         diff = da.add(db, fill_value=0)
